@@ -2,6 +2,7 @@ package Business::OnlinePayment::Litle::ErrorCodes;
 use strict;
 use warnings;
 
+our $VERSION = '0.952'; # VERSION
 use Exporter 'import';
 use vars qw(@EXPORT_OK);
 
@@ -11,6 +12,7 @@ our %ERRORS;
 
 # ABSTRACT: Business::OnlinePayment::Litle::ErrorCodes - Error code hash
 
+
 sub lookup {
     my $code = shift;
     return if not $code or not defined $ERRORS{$code};
@@ -355,8 +357,6 @@ sub lookup {
                      notes => 'Invalid Bank Routing Number'
                    }
         );
-
-
 1;
 
 __END__
@@ -371,48 +371,13 @@ Business::OnlinePayment::Litle::ErrorCodes - Business::OnlinePayment::Litle::Err
 
 =head1 VERSION
 
-version 0.951
+version 0.952
 
-=head1 SYNOPSIS
+=head1 METHODS
 
-    use Business::OnlinePayment::Litle::ErrorCodes 'lookup';
-    my $result = lookup( $result_code );
-    # $result = { reason => ..., notes => ..., status => ... };
+=head2 lookup
 
-or
-
-    use Business::OnlinePayment::Litle::ErrorCodes '%ERRORS';
-    my $result = $ERRORS{ $result_code };
-
-=head1 DESCRIPTION
-
-This module provides a method to lookup extended codes to Litle & Co API responses
-
-=head2 lookup CODE
-
-Takes the result code returned in your Litle response.  Returns a 
-hashref containing three keys, C<reason>, C<status>, and C<notes> (which may be empty) if
-the lookup is successful, undef otherwise.  This allows for more descriptive error messages, as well as categorization into hard and soft failure types.
-
-=head1 NAME
-
-Business::OnlinePayment::Litle::ErrorCodes - Map given codes with more verbose messages
-
-=head1 AUTHOR
-
-Jason (Jayce^) Hall <jayce@lug-nut.com>
-
-=head1 AKNOWLEDGEMENTS
-
-Thomas Sibley <trs@bestpractical.com> wrote the AIM module.  This follows the same pattern
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (c) 2010.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.3 or,
-at your option, any later version of Perl 5 you may have available.
+Return the information associated with an error code
 
 =head1 AUTHOR
 
@@ -427,6 +392,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 VERSION
 
-version 0.951
+version 0.952
 
 =cut
